==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Dziennik.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.TypOperacji;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Dziennik extends GenericDPSObject {
    /**
     * DZIENNIK.ID
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private Long id;

    /**
     * DZIENNIK.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private Long pracownikId;

    /**
     * DZIENNIK.DATA
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private Date data;

    /**
     * DZIENNIK.OBIEKT_ID
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private Long obiektId;

    /**
     * DZIENNIK.TYP_OPERACJI
     *
     * @mbggenerated 2014-03-10 10:45:44
     */
    private TypOperacji typOperacji;

    /**
     * @mbggenerated 2014-03-10 10:45:44
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DZIENNIK.ID
     * @mbggenerated 2014-03-10 10:45:44
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DZIENNIK.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DZIENNIK.PRACOWNIK_ID
     * @mbggenerated 2014-03-10 10:45:44
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * DZIENNIK.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return DZIENNIK.DATA
     * @mbggenerated 2014-03-10 10:45:44
     */
    public Date getData() {
        return data;
    }

    /**
     * DZIENNIK.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return DZIENNIK.OBIEKT_ID
     * @mbggenerated 2014-03-10 10:45:44
     */
    public Long getObiektId() {
        return obiektId;
    }

    /**
     * DZIENNIK.OBIEKT_ID
     *
     * @param obiektId
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setObiektId(Long obiektId) {
        this.obiektId = obiektId;
    }

    /**
     * @return DZIENNIK.TYP_OPERACJI
     * @mbggenerated 2014-03-10 10:45:44
     */
    public TypOperacji getTypOperacji() {
        return typOperacji;
    }

    /**
     * DZIENNIK.TYP_OPERACJI
     *
     * @param typOperacji
     * @mbggenerated 2014-03-10 10:45:44
     */
    public void setTypOperacji(TypOperacji typOperacji) {
        this.typOperacji = typOperacji;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:44
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Dziennik other = (Dziennik) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getObiektId() == null ? other.getObiektId() == null : this.getObiektId().equals(other.getObiektId()))
            && (this.getTypOperacji() == null ? other.getTypOperacji() == null : this.getTypOperacji().equals(other.getTypOperacji()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:44
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getObiektId() == null) ? 0 : getObiektId().hashCode());
        result = prime * result + ((getTypOperacji() == null) ? 0 : getTypOperacji().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:44
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", data=").append(data);
        sb.append(", obiektId=").append(obiektId);
        sb.append(", typOperacji=").append(typOperacji);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Dziennik.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.TypOperacji;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Dziennik extends GenericDPSObject {
    /**
     * DZIENNIK.ID
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private Long id;

    /**
     * DZIENNIK.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private Long pracownikId;

    /**
     * DZIENNIK.DATA
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private Date data;

    /**
     * DZIENNIK.OBIEKT_ID
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private Long obiektId;

    /**
     * DZIENNIK.TYP_OPERACJI
     *
     * @mbggenerated 2014-03-13 16:02:50
     */
    private TypOperacji typOperacji;

    /**
     * @mbggenerated 2014-03-13 16:02:50
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DZIENNIK.ID
     * @mbggenerated 2014-03-13 16:02:50
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DZIENNIK.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DZIENNIK.PRACOWNIK_ID
     * @mbggenerated 2014-03-13 16:02:50
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * DZIENNIK.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return DZIENNIK.DATA
     * @mbggenerated 2014-03-13 16:02:50
     */
    public Date getData() {
        return data;
    }

    /**
     * DZIENNIK.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return DZIENNIK.OBIEKT_ID
     * @mbggenerated 2014-03-13 16:02:50
     */
    public Long getObiektId() {
        return obiektId;
    }

    /**
     * DZIENNIK.OBIEKT_ID
     *
     * @param obiektId
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setObiektId(Long obiektId) {
        this.obiektId = obiektId;
    }

    /**
     * @return DZIENNIK.TYP_OPERACJI
     * @mbggenerated 2014-03-13 16:02:50
     */
    public TypOperacji getTypOperacji() {
        return typOperacji;
    }

    /**
     * DZIENNIK.TYP_OPERACJI
     *
     * @param typOperacji
     * @mbggenerated 2014-03-13 16:02:50
     */
    public void setTypOperacji(TypOperacji typOperacji) {
        this.typOperacji = typOperacji;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:50
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Dziennik other = (Dziennik) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getObiektId() == null ? other.getObiektId() == null : this.getObiektId().equals(other.getObiektId()))
            && (this.getTypOperacji() == null ? other.getTypOperacji() == null : this.getTypOperacji().equals(other.getTypOperacji()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:50
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getObiektId() == null) ? 0 : getObiektId().hashCode());
        result = prime * result + ((getTypOperacji() == null) ? 0 : getTypOperacji().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:50
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", data=").append(data);
        sb.append(", obiektId=").append(obiektId);
        sb.append(", typOperacji=").append(typOperacji);
        sb.append("]");
        return sb.toString();
    }
}
